pub struct S7Server { /* private fields */ }Expand description
TCP listener that accepts connections and runs the full S7 pipeline per connection.
Implementations
Sourceimpl S7Server
impl S7Server
Sourcepub async fn bind(config: ServerConfig) -> Result<Self>
pub async fn bind(config: ServerConfig) -> Result<Self>
Bind a TCP listener at config.bind_addr.
Sourcepub fn local_addr(&self) -> Result<SocketAddr>
pub fn local_addr(&self) -> Result<SocketAddr>
Return the local address the server is listening on.